[Spice-commits] server/display-channel.c server/red_worker.c server/stream.c server/stream.h

Frediano Ziglio fziglio at kemper.freedesktop.org
Wed Dec 2 04:45:51 PST 2015


 server/display-channel.c |   10 +++++-----
 server/red_worker.c      |    2 +-
 server/stream.c          |    2 +-
 server/stream.h          |    4 +++-
 4 files changed, 10 insertions(+), 8 deletions(-)

New commits:
commit 5161132ec71ae5e7052b87461f97ece91e1b19d0
Author: Marc-André Lureau <marcandre.lureau at gmail.com>
Date:   Tue Oct 1 17:14:44 2013 +0200

    display: rename detach_streams_behind
    
    Acked-by: Fabiano FidĂȘncio <fidencio at redhat.com>

diff --git a/server/red_worker.c b/server/red_worker.c
index 4702949..6045ae5 100644
--- a/server/red_worker.c
+++ b/server/red_worker.c
@@ -333,7 +333,7 @@ static inline int red_handle_surfaces_dependencies(DisplayChannel *display, Draw
                 QRegion depend_region;
                 region_init(&depend_region);
                 region_add(&depend_region, &drawable->red_drawable->surfaces_rects[x]);
-                detach_streams_behind(display, &depend_region, NULL);
+                stream_detach_behind(display, &depend_region, NULL);
             }
         }
     }
diff --git a/server/stream.c b/server/stream.c
index 3bd91b6..cb7271e 100644
--- a/server/stream.c
+++ b/server/stream.c
@@ -837,7 +837,7 @@ static void detach_stream_gracefully(DisplayChannel *display, Stream *stream,
  *           involves sending an upgrade image to the client, this drawable won't be rendered
  *           (see dcc_detach_stream_gracefully).
  */
-void detach_streams_behind(DisplayChannel *display, QRegion *region, Drawable *drawable)
+void stream_detach_behind(DisplayChannel *display, QRegion *region, Drawable *drawable)
 {
     Ring *ring = &display->streams;
     RingItem *item = ring_get_head(ring);
diff --git a/server/stream.h b/server/stream.h
index c436c2e..214d1df 100644
--- a/server/stream.h
+++ b/server/stream.h
@@ -152,6 +152,9 @@ void                  stream_timeout                                (DisplayChan
 void                  stream_detach_and_stop                        (DisplayChannel *display);
 void                  stream_trace_add_drawable                     (DisplayChannel *display,
                                                                      Drawable *item);
+void                  stream_detach_behind                          (DisplayChannel *display,
+                                                                     QRegion *region,
+                                                                     Drawable *drawable);
 
 void                  stream_agent_unref                            (DisplayChannel *display,
                                                                      StreamAgent *agent);
@@ -159,6 +162,5 @@ void                  stream_agent_stats_print                      (StreamAgent
 void                  stream_agent_stop                             (StreamAgent *agent);
 
 void detach_stream(DisplayChannel *display, Stream *stream, int detach_sized);
-void detach_streams_behind(DisplayChannel *display, QRegion *region, Drawable *drawable);
 
 #endif /* STREAM_H */


More information about the Spice-commits mailing list
diff --git a/server/display-channel.c b/server/display-channel.c
index 2bf65a8..a37e651 100644
--- a/server/display-channel.c
+++ b/server/display-channel.c
@@ -713,7 +713,7 @@ static int current_add_with_shadow(DisplayChannel *display, Ring *ring, Drawable
 
     // only primary surface streams are supported
     if (is_primary_surface(display, item->surface_id)) {
-        detach_streams_behind(display, &shadow->base.rgn, NULL);
+        stream_detach_behind(display, &shadow->base.rgn, NULL);
     }
 
     ring_add(ring, &shadow->base.siblings_link);
@@ -726,7 +726,7 @@ static int current_add_with_shadow(DisplayChannel *display, Ring *ring, Drawable
         streams_update_visible_region(display, item);
     } else {
         if (is_primary_surface(display, item->surface_id)) {
-            detach_streams_behind(display, &item->tree_item.base.rgn, item);
+            stream_detach_behind(display, &item->tree_item.base.rgn, item);
         }
     }
     stat_add(&display->add_stat, start_time);
@@ -836,14 +836,14 @@ static int current_add(DisplayChannel *display, Ring *ring, Drawable *drawable)
         current_add_drawable(display, drawable, ring);
     } else {
         /*
          * red_detach_streams_behind can affect the current tree since
          * it may trigger calls to display_channel_draw. Thus, the
          * drawable should be added to the tree before calling
-         * red_detach_streams_behind
+         * stream_detach_behind
          */
         current_add_drawable(display, drawable, ring);
         if (is_primary_surface(display, drawable->surface_id)) {
-            detach_streams_behind(display, &drawable->tree_item.base.rgn, drawable);
+            stream_detach_behind(display, &drawable->tree_item.base.rgn, drawable);
         }
     }
     region_destroy(&exclude_rgn);
@@ -836,14 +836,14 @@ static int current_add(DisplayChannel *display, Ring *ring, Drawable *drawable)
     } else {
         /*
-         * red_detach_streams_behind can affect the current tree since
+         * stream_detach_behind can affect the current tree since
          * it may trigger calls to display_channel_draw. Thus, the
          * drawable should be added to the tree before calling